local HealingTracker = _G.HealingTracker
local OptionsFrame = HealingTracker.OptionsFrame
local TrackerFrame = HealingTracker.TrackerFrame
local window = nil
local AceGUI = LibStub("AceGUI-3.0")
local LSM = LibStub("LibSharedMedia-3.0")

function OptionsFrame:Init()

	local pdb = HealingTracker.ProfileOptions

	window = AceGUI:Create("Window")
	window:SetWidth(530)
	window:SetHeight(415)
	window:SetPoint("CENTER", UIParent, "CENTER", 0, 0)
	window:SetLayout("Flow")
	window:SetTitle("Healing Tracker Settings")
	window:EnableResize(false)

	local lpanel = AceGUI:Create("InlineGroup")
	lpanel:SetWidth(325)
	lpanel:SetLayout("Flow")
	lpanel:SetTitle("Visualization")
	
	local rpanel = AceGUI:Create("InlineGroup")
	rpanel:SetWidth(180)
	rpanel:SetLayout("List")
	rpanel:SetTitle("Header")
	rpanel:SetPoint("TOP", 0)

	local dpanel = AceGUI:Create("InlineGroup")
	dpanel:SetWidth(510)
	dpanel:SetLayout("Flow")
	dpanel:SetTitle("Data")

	window:AddChild(lpanel)
	window:AddChild(rpanel)
	window:AddChild(dpanel)
	
	InitVisual(lpanel, pdb)
	InitData(dpanel, pdb)
	InitHeader(rpanel, pdb)
	InitBottom(window)

	window.lpanel = lpanel
	window.dpanel = dpanel
	window.rpanel = rpanel

	window:Hide()
end

function InitVisual(lpanel, pdb)
	
	local bars = AceGUI:Create("Dropdown")
	bars:SetLabel("Bar Texture")
	bars:SetWidth(150)
	bars:SetList({})
	local channels = LSM:List("statusbar")
	table.foreach(channels, function(k,v)
		local vstr = tostring(v)
		bars:AddItem(v,v)
	end)
	bars:SetCallback("OnValueChanged", function(f, e, value)
			pdb.Bars.Texture = value
			TrackerFrame:Redraw()
			TrackerFrame:UpdateHeights()
			TrackerFrame:UpdateBars()
		end)
	bars:SetValue(pdb.Bars.Texture)
	lpanel.bars = bars
	
	local fonts = AceGUI:Create("Dropdown")
	fonts:SetLabel("Bar Font")
	fonts:SetWidth(150)
	fonts:SetList({})
	
	local fontList = LSM:List("font")
	table.foreach(fontList, function(k,v)
		local vstr = tostring(v)
		fonts:AddItem(v, v)
	end)
	fonts:SetCallback("OnValueChanged",
		function(f, e, value)
			pdb.Bars.Font = value
			TrackerFrame:Redraw()
			TrackerFrame:UpdateHeights()
			TrackerFrame:UpdateBars()
		end)
	fonts:SetValue(pdb.Bars.Font)
	lpanel.fonts = fonts
	
	local sizing = AceGUI:Create("Slider")
	sizing:SetLabel("Font Size")
	sizing:SetSliderValues(7, 35, 1)
	sizing:SetCallback("OnValueChanged", function(self, event, value)
			pdb.Bars.FontSize = value
			TrackerFrame:Redraw()
			TrackerFrame:UpdateHeights()
			TrackerFrame:UpdateBars()
		end)
	sizing:SetWidth(150)
	sizing:SetValue(pdb.Bars.FontSize)
	lpanel.sizing = sizing
	
	local heights = AceGUI:Create("Slider")
	heights:SetLabel("Bar Height")
	heights:SetSliderValues(10, 40, 1)
	heights:SetCallback("OnValueChanged", function(self, event, value)
			pdb.Bars.Height = value
			TrackerFrame:Redraw()
			TrackerFrame:UpdateHeights()
			TrackerFrame:UpdateBars()
		end)
	heights:SetWidth(150)
	heights:SetValue(pdb.Bars.Height)
	lpanel.heights = heights
	
	lpanel:AddChild(bars)
	lpanel:AddChild(fonts)
	lpanel:AddChild(heights)
	lpanel:AddChild(sizing)
	
end

function InitData(dpanel, pdb)
	
	local visual = AceGUI:Create("Dropdown")
	visual:SetLabel("Data")
	visual:SetWidth(180)
	visual:SetList({})
	local visualList = {[0]="Don't Keep", [1]="Only Boss Fights", [2]="All Combat Data"}
	table.foreach(visualList, function(k,v) visual:AddItem(k,v) end)
	visual:SetCallback("OnValueChanged", function(self, event, value) pdb.Keep = value end)
	visual:SetValue(pdb.Keep)
	dpanel.visual = visual
	
	local keepDuration = AceGUI:Create("Dropdown")
	keepDuration:SetLabel("Keep By Duration")
	keepDuration:SetWidth(180)
	local durationList = {
		[0]="All Combat Data", 
		[5]="Longer than 5 secs", 
		[10]="Longer than 10 secs", 
		[15]="Longer than 15 secs", 
		[30]="Longer than 30 secs",
		[60]="Longer than 1 min"}
	keepDuration:SetList(durationList)
	keepDuration:SetCallback("OnValueChanged", function(self, event, value) pdb.KeepDuration = value end)
	keepDuration:SetValue(pdb.KeepDuration)
	dpanel.keepDuration = keepDuration
			
	local pointlessSlider = AceGUI:Create("Slider")
	pointlessSlider:SetLabel("Pointless Limit")
	pointlessSlider:SetSliderValues(20, 80, 1)
	pointlessSlider:SetCallback("OnValueChanged", function(self, event, value) pdb.PointlessLimit = (value) / 100 end)
	pointlessSlider:SetWidth(150)
	pointlessSlider:SetValue((pdb.PointlessLimit)*100)
	dpanel.pointlessSlider = pointlessSlider

	local colListMain = {[1]="Tracker Point", [2]="Total Heal", [12]="Total HPS", [3]="Aidful Heal", [7]="Active Heal", [17]="Active HPS", [13]="Aidful HPS", [4]="Pointless Heal", [14]="Pointless HPS", [5]="Mana", [6]="Losing Mana" }
	local colListOther = {[0]="None", [1]="Tracker Point", [2]="Total Heal", [12]="Total HPS", [3]="Aidful Heal", [7]="Active Heal", [17]="Active HPS", [13]="Aidful HPS", [4]="Pointless Heal", [14]="Pointless HPS", [5]="Mana", [6]="Losing Mana"}

	local maincol = AceGUI:Create("Dropdown")
	maincol:SetLabel("First Column")
	maincol:SetWidth(150)
	maincol:SetList(colListMain)
	maincol:SetCallback("OnValueChanged", function(self, event, value)
		local rval = value
		if rval > 10 then
			pdb.Columns.RightHPS = true
			rval = rval - 10
		else
			pdb.Columns.RightHPS = nil
		end
		pdb.Columns.Right = rval
		HealingTracker.Segments:SortCurrent()
		HealingTracker.TrackerFrame:SetSegment(HealingTracker.Segments.Current)
		TrackerFrame:Redraw()
		TrackerFrame:UpdateHeights()
		TrackerFrame:UpdateBars()
		end)
	local rvalue = pdb.Columns.Right
	if pdb.Columns.RightHPS then
		rvalue = rvalue + 10
	end
	maincol:SetValue(rvalue)
	dpanel.maincol = maincol

	local innercol = AceGUI:Create("Dropdown")
	innercol:SetLabel("Second Column")
	innercol:SetWidth(150)
	innercol:SetList(colListOther)
	innercol:SetCallback("OnValueChanged", function(self, event, value)
		local mval = value
		if mval > 10 then
			pdb.Columns.MidHPS = true
			mval = mval - 10
		else
			pdb.Columns.MidHPS = nil
		end
		pdb.Columns.Mid = mval
		HealingTracker.Segments:SortCurrent()
		HealingTracker.TrackerFrame:SetSegment(HealingTracker.Segments.Current)
		TrackerFrame:Redraw()
		TrackerFrame:UpdateHeights()
		TrackerFrame:UpdateBars()
		end)
	local mvalue = pdb.Columns.Mid
	if pdb.Columns.MidHPS then
		mvalue = mvalue + 10
	end
	innercol:SetValue(mvalue)
	dpanel.innercol = innercol

	local hideCheck = AceGUI:Create("CheckBox")
	hideCheck:SetLabel("Hide In Combat")
	hideCheck:SetWidth(150)
	hideCheck:SetCallback("OnValueChanged", function(self, event, value)
		if value then
			pdb.HideInCombat = 1
		else
			pdb.HideInCombat = 0
		end
	end)
	if pdb.HideInCombat == 1 then hideCheck:SetValue(true) end
	dpanel.hideCheck = hideCheck

	local mtSlider = AceGUI:Create("Slider")
	mtSlider:SetLabel("Losing Mana Threshold (secs)")
	mtSlider:SetSliderValues(5, 60, 1)
	mtSlider:SetCallback("OnValueChanged", function(self, event, value) pdb.ManaThreshold = value end)
	mtSlider:SetWidth(238)
	mtSlider:SetValue(pdb.ManaThreshold)
	dpanel.mtSlider = mtSlider

	local htSlider = AceGUI:Create("Slider")
	htSlider:SetLabel("Active Heal Threshold (secs)")
	htSlider:SetSliderValues(5, 60, 1)
	htSlider:SetCallback("OnValueChanged", function(self, event, value) pdb.ActiveHealThreshold = value end)
	htSlider:SetWidth(238)
	htSlider:SetValue(pdb.ActiveHealThreshold)
	dpanel.htSlider = htSlider

	dpanel:AddChild(visual)
	dpanel:AddChild(maincol)
	dpanel:AddChild(pointlessSlider)
	dpanel:AddChild(keepDuration)
	dpanel:AddChild(innercol)
	dpanel:AddChild(hideCheck)
	dpanel:AddChild(mtSlider)
	dpanel:AddChild(htSlider)

end

function InitHeader(rpanel, pdb)
	
	local reportCheck = AceGUI:Create("CheckBox")
	reportCheck:SetLabel("Report Segment")
	reportCheck:SetCallback("OnValueChanged", function(self, event, value)
		pdb.HeaderButtons.Report = value
		TrackerFrame:Redraw()
	end)
	if pdb.HeaderButtons.Report then reportCheck:SetValue(true) end
	rpanel.reportCheck = reportCheck

	local optionsCheck = AceGUI:Create("CheckBox")
	optionsCheck:SetLabel("Options")
	optionsCheck:SetCallback("OnValueChanged", function(self, event, value)
		pdb.HeaderButtons.Options = value
		TrackerFrame:Redraw()
	end)
	if pdb.HeaderButtons.Options then optionsCheck:SetValue(true) end
	rpanel.optionsCheck = optionsCheck

	local resetCheck = AceGUI:Create("CheckBox")
	resetCheck:SetLabel("Reset Segments")
	resetCheck:SetCallback("OnValueChanged", function(self, event, value)
		pdb.HeaderButtons.Reset = value
		TrackerFrame:Redraw()
	end)
	if pdb.HeaderButtons.Reset then resetCheck:SetValue(true) end
	rpanel.resetCheck = resetCheck

	local closeCheck = AceGUI:Create("CheckBox")
	closeCheck:SetLabel("Hide Tracker")
	closeCheck:SetCallback("OnValueChanged", function(self, event, value)
		pdb.HeaderButtons.Close = value
		TrackerFrame:Redraw()
	end)
	if pdb.HeaderButtons.Close then closeCheck:SetValue(true) end
	rpanel.closeCheck = closeCheck

	rpanel:AddChild(reportCheck)
	rpanel:AddChild(optionsCheck)
	rpanel:AddChild(resetCheck)
	rpanel:AddChild(closeCheck)

end

function InitBottom(window)
	
	local pdb = HealingTracker.ProfileOptions
	
	local pbottom = AceGUI:Create("SimpleGroup")
	pbottom:SetWidth(550)
	pbottom:SetHeight(25)
	pbottom:SetLayout("Flow")
	
	local bottom1 = AceGUI:Create("SimpleGroup")
	bottom1:SetWidth(404)
	bottom1:SetHeight(25)
	bottom1:SetLayout("Flow")

	local bottom2 = AceGUI:Create("SimpleGroup")
	bottom2:SetWidth(100)
	bottom2:SetHeight(25)
	bottom2:SetLayout("Flow")
	
	local rdefaults = AceGUI:Create("Button")
	rdefaults:SetText("Defaults")
	rdefaults:SetWidth(100)
	rdefaults:SetCallback("OnClick", function()
		HealingTracker:ApplyDefaults(1)
		window.lpanel.bars:SetValue(pdb.Bars.Texture)
		window.lpanel.fonts:SetValue(pdb.Bars.Font)
		window.lpanel.sizing:SetValue(pdb.Bars.FontSize)
		window.lpanel.heights:SetValue(pdb.Bars.Height)
		window.dpanel.visual:SetValue(pdb.Keep)
		window.dpanel.keepDuration:SetValue(pdb.KeepDuration)
		window.dpanel.pointlessSlider:SetValue((pdb.PointlessLimit)*100)
		window.dpanel.maincol:SetValue(pdb.Columns.Right)
		window.dpanel.innercol:SetValue(pdb.Columns.Mid)
		window.dpanel.hideCheck:SetValue(pdb.HideInCombat == 1)
		window.rpanel.reportCheck:SetValue(pdb.HeaderButtons.Report)
		window.rpanel.optionsCheck:SetValue(pdb.HeaderButtons.Options)
		window.rpanel.resetCheck:SetValue(pdb.HeaderButtons.Reset)
		window.rpanel.closeCheck:SetValue(pdb.HeaderButtons.Close)
		TrackerFrame:Redraw()
		TrackerFrame:UpdateHeights()
		TrackerFrame:UpdateBars()
	end)

	local close = AceGUI:Create("Button")
	close:SetText("Close")
	close:SetWidth(100)
	close:SetCallback("OnClick", function() window:Hide() end)

	bottom1:AddChild(rdefaults)
	pbottom:AddChild(bottom1)
	pbottom:AddChild(bottom2)
	bottom2:AddChild(close)
	window:AddChild(pbottom)
end

-- show frame
function OptionsFrame:Show()
	window:Show()
end

function OptionsFrame:Hide()
	window:Hide()
end

function OptionsFrame:Reset()
end

function OptionsFrame:Refresh()
end

function OptionsFrame:Save()
end
